@@ -1,14 +1,10 @@
-from hashlib import new
+from t2wml.mapping.datamart_edges import clean_id
 import yaml
 import os
 import warnings
 from pathlib import Path
 from shutil import copyfile
-from t2wml.wikification.utility_functions import add_entities_from_file
-from t2wml.wikification.item_table import Wikifier
-from t2wml.spreadsheets.sheet import Sheet, SpreadsheetFile
-from t2wml.mapping.statement_mapper import YamlMapper
-from t2wml.knowledge_graph import KnowledgeGraph
+from t2wml.spreadsheets.sheet import SpreadsheetFile
 from t2wml.utils.t2wml_exceptions import FileWithThatNameInProject, FileNotPresentInProject, InvalidProjectDirectory
 from t2wml.settings import DEFAULT_SPARQL_ENDPOINT
 
@@ -48,6 +44,9 @@ class Project:
 
         self.cache_id=cache_id
 
+    @property
+    def dataset_id(self):
+        return clean_id(self.title)
     
     def _load_data_files_from_project(self, data_files):
         self.data_files=data_files or {}
@@ -216,7 +215,7 @@ class Project:
             file_path=full_path.relative_to(root)
         return Path(file_path).as_posix()
     
-    def _get_full_path(self, file_path):
+    def get_full_path(self, file_path):
         normalized_path=self._normalize_path(file_path)
         return os.path.join(self.directory, normalized_path)
     
@@ -230,6 +229,10 @@ class Project:
             return True
         if file_path in self.entity_files:
             return True
+        for key, data_file in self.annotations.items():
+            for s_key, sheet in data_file.items():
+                if file_path in sheet["val_arr"]:
+                    return True
         return False
     
     def delete_file_from_project(self, file_path, delete_from_fs=False):
@@ -272,7 +275,7 @@ class Project:
 
         if delete_from_fs:
             try:
-                del_path=self._get_full_path(del_val)
+                del_path=self.get_full_path(del_val)
                 os.remove(del_path)
             except Exception as e:
                 print(e)
@@ -288,7 +291,7 @@ class Project:
 
         if not self.path_in_files(old_name):
             raise ValueError("The file you are trying to rename does not exist in project")
-        new_file_path=self._get_full_path(new_name)
+        new_file_path=self.get_full_path(new_name)
         if os.path.isfile(new_file_path):
             raise ValueError("The new name you have provided already exists in the project directory")
             
@@ -325,7 +328,10 @@ class Project:
 
         
         if rename_in_fs:
-            old_file_path=self._get_full_path(old_name)
+            new_path=Path(new_file_path)
+            full_folder_path=new_path.parent
+            os.makedirs(full_folder_path, exist_ok=True)
+            old_file_path=self.get_full_path(old_name)
             os.rename(old_file_path, new_file_path)
         
 
